==> certificatemanager-0.14.1-sources.jar: software/amazon/awscdk/services/certificatemanager/cloudformation/CertificateResource.java <==
package software.amazon.awscdk.services.certificatemanager.cloudformation;

/**
 * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-certificatemanager-certificate.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.7.8 (build 100f5ad)", date = "2018-10-26T17:54:45.057Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.certificatemanager.$Module.class, fqn = "@aws-cdk/aws-certificatemanager.cloudformation.CertificateResource")
public class CertificateResource extends software.amazon.awscdk.Resource {
    protected CertificateResource(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
        super(mode);
    }
    static {
        RESOURCE_TYPE_NAME = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.certificatemanager.cloudformation.CertificateResource.class, "resourceTypeName", java.lang.String.class);
    }
    /**
     * Creates a new ``AWS::CertificateManager::Certificate``.
     * @param parent the ``cdk.Construct`` this ``CertificateResource`` is a part of
     * @param name the name of the resource in the ``cdk.Construct`` tree
     * @param properties the properties of this ``CertificateResource``
     */
    public CertificateResource(final software.amazon.awscdk.Construct parent, final java.lang.String name, final software.amazon.awscdk.services.certificatemanager.cloudformation.CertificateResourceProps properties) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.Jsii);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, java.util.stream.Stream.concat(java.util.stream.Stream.concat(java.util.stream.Stream.of(java.util.Objects.requireNonNull(parent, "parent is required")), java.util.stream.Stream.of(java.util.Objects.requireNonNull(name, "name is required"))), java.util.stream.Stream.of(java.util.Objects.requireNonNull(properties, "properties is required"))).toArray());
    }

    @Override
    protected java.util.Map<java.lang.String, java.lang.Object> renderProperties(@javax.annotation.Nullable final java.lang.Object properties) {
        return this.jsiiCall("renderProperties", java.util.Map.class, java.util.stream.Stream.of(properties).toArray());
    }

    @Override
    protected java.util.Map<java.lang.String, java.lang.Object> renderProperties() {
        return this.jsiiCall("renderProperties", java.util.Map.class);
    }
    /**
     * The CloudFormation resource type name for this resource class.
     */
    public final static java.lang.String RESOURCE_TYPE_NAME;

    public java.lang.String getCertificateArn() {
        return this.jsiiGet("certificateArn", java.lang.String.class);
    }

    public software.amazon.awscdk.services.certificatemanager.cloudformation.CertificateResourceProps getPropertyOverrides() {
        return this.jsiiGet("propertyOverrides", software.amazon.awscdk.services.certificatemanager.cloudformation.CertificateResourceProps.class);
    }
    /**
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-certificatemanager-certificate-domainvalidationoption.html
     */
    public static interface DomainValidationOptionProperty extends software.amazon.jsii.JsiiSerializable {
        /**
         * ``CertificateResource.DomainValidationOptionProperty.DomainName``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-certificatemanager-certificate-domainvalidationoption.html#cfn-certificatemanager-certificate-domainvalidationoptions-domainname
         */
        java.lang.Object getDomainName();
        /**
         * ``CertificateResource.DomainValidationOptionProperty.DomainName``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-certificatemanager-certificate-domainvalidationoption.html#cfn-certificatemanager-certificate-domainvalidationoptions-domainname
         */
        void setDomainName(final java.lang.String value);
        /**
         * ``CertificateResource.DomainValidationOptionProperty.DomainName``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-certificatemanager-certificate-domainvalidationoption.html#cfn-certificatemanager-certificate-domainvalidationoptions-domainname
         */
        void setDomainName(final software.amazon.awscdk.Token value);
        /**
         * ``CertificateResource.DomainValidationOptionProperty.ValidationDomain``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-certificatemanager-certificate-domainvalidationoption.html#cfn-certificatemanager-certificate-domainvalidationoption-validationdomain
         */
        java.lang.Object getValidationDomain();
        /**
         * ``CertificateResource.DomainValidationOptionProperty.ValidationDomain``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-certificatemanager-certificate-domainvalidationoption.html#cfn-certificatemanager-certificate-domainvalidationoption-validationdomain
         */
        void setValidationDomain(final java.lang.String value);
        /**
         * ``CertificateResource.DomainValidationOptionProperty.ValidationDomain``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-certificatemanager-certificate-domainvalidationoption.html#cfn-certificatemanager-certificate-domainvalidationoption-validationdomain
         */
        void setValidationDomain(final software.amazon.awscdk.Token value);

        /**
         * @return a {@link Builder} of {@link DomainValidationOptionProperty}
         */
        static Builder builder() {
            return new Builder();
        }

        /**
         * A builder for {@link DomainValidationOptionProperty}
         */
        final class Builder {
            private java.lang.Object _domainName;
            private java.lang.Object _validationDomain;

            /**
             * Sets the value of DomainName
             * @param value ``CertificateResource.DomainValidationOptionProperty.DomainName``
             * @return {@code this}
             */
            public Builder withDomainName(final java.lang.String value) {
                this._domainName = java.util.Objects.requireNonNull(value, "domainName is required");
                return this;
            }
            /**
             * Sets the value of DomainName
             * @param value ``CertificateResource.DomainValidationOptionProperty.DomainName``
             * @return {@code this}
             */
            public Builder withDomainName(final software.amazon.awscdk.Token value) {
                this._domainName = java.util.Objects.requireNonNull(value, "domainName is required");
                return this;
            }
            /**
             * Sets the value of ValidationDomain
             * @param value ``CertificateResource.DomainValidationOptionProperty.ValidationDomain``
             * @return {@code this}
             */
            public Builder withValidationDomain(final java.lang.String value) {
                this._validationDomain = java.util.Objects.requireNonNull(value, "validationDomain is required");
                return this;
            }
            /**
             * Sets the value of ValidationDomain
             * @param value ``CertificateResource.DomainValidationOptionProperty.ValidationDomain``
             * @return {@code this}
             */
            public Builder withValidationDomain(final software.amazon.awscdk.Token value) {
                this._validationDomain = java.util.Objects.requireNonNull(value, "validationDomain is required");
                return this;
            }

            /**
             * Builds the configured instance.
             * @return a new instance of {@link DomainValidationOptionProperty}
             * @throws NullPointerException if any required attribute was not provided
             */
            public DomainValidationOptionProperty build() {
                return new DomainValidationOptionProperty() {
                    private java.lang.Object $domainName = java.util.Objects.requireNonNull(_domainName, "domainName is required");
                    private java.lang.Object $validationDomain = java.util.Objects.requireNonNull(_validationDomain, "validationDomain is required");

                    @Override
                    public java.lang.Object getDomainName() {
                        return this.$domainName;
                    }

                    @Override
                    public void setDomainName(final java.lang.String value) {
                        this.$domainName = java.util.Objects.requireNonNull(value, "domainName is required");
                    }

                    @Override
                    public void setDomainName(final software.amazon.awscdk.Token value) {
                        this.$domainName = java.util.Objects.requireNonNull(value, "domainName is required");
                    }

                    @Override
                    public java.lang.Object getValidationDomain() {
                        return this.$validationDomain;
                    }

                    @Override
                    public void setValidationDomain(final java.lang.String value) {
                        this.$validationDomain = java.util.Objects.requireNonNull(value, "validationDomain is required");
                    }

                    @Override
                    public void setValidationDomain(final software.amazon.awscdk.Token value) {
                        this.$validationDomain = java.util.Objects.requireNonNull(value, "validationDomain is required");
                    }

                };
            }
        }

        /**
         * A proxy class which represents a concrete javascript instance of this type.
         */
        final static class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.certificatemanager.cloudformation.CertificateResource.DomainValidationOptionProperty {
            protected Jsii$Proxy(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
                super(mode);
            }

            /**
             * ``CertificateResource.DomainValidationOptionProperty.DomainName``
             * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-certificatemanager-certificate-domainvalidationoption.html#cfn-certificatemanager-certificate-domainvalidationoptions-domainname
             */
            @Override
            public java.lang.Object getDomainName() {
                return this.jsiiGet("domainName", java.lang.Object.class);
            }

            /**
             * ``CertificateResource.DomainValidationOptionProperty.DomainName``
             * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-certificatemanager-certificate-domainvalidationoption.html#cfn-certificatemanager-certificate-domainvalidationoptions-domainname
             */
            @Override
            public void setDomainName(final java.lang.String value) {
                this.jsiiSet("domainName", java.util.Objects.requireNonNull(value, "domainName is required"));
            }

            /**
             * ``CertificateResource.DomainValidationOptionProperty.DomainName``
             * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-certificatemanager-certificate-domainvalidationoption.html#cfn-certificatemanager-certificate-domainvalidationoptions-domainname
             */
            @Override
            public void setDomainName(final software.amazon.awscdk.Token value) {
                this.jsiiSet("domainName", java.util.Objects.requireNonNull(value, "domainName is required"));
            }

            /**
             * ``CertificateResource.DomainValidationOptionProperty.ValidationDomain``
             * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-certificatemanager-certificate-domainvalidationoption.html#cfn-certificatemanager-certificate-domainvalidationoption-validationdomain
             */
            @Override
            public java.lang.Object getValidationDomain() {
                return this.jsiiGet("validationDomain", java.lang.Object.class);
            }

            /**
             * ``CertificateResource.DomainValidationOptionProperty.ValidationDomain``
             * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-certificatemanager-certificate-domainvalidationoption.html#cfn-certificatemanager-certificate-domainvalidationoption-validationdomain
             */
            @Override
            public void setValidationDomain(final java.lang.String value) {
                this.jsiiSet("validationDomain", java.util.Objects.requireNonNull(value, "validationDomain is required"));
            }

            /**
             * ``CertificateResource.DomainValidationOptionProperty.ValidationDomain``
             * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-certificatemanager-certificate-domainvalidationoption.html#cfn-certificatemanager-certificate-domainvalidationoption-validationdomain
             */
            @Override
            public void setValidationDomain(final software.amazon.awscdk.Token value) {
                this.jsiiSet("validationDomain", java.util.Objects.requireNonNull(value, "validationDomain is required"));
            }
        }
    }
}

==> certificatemanager-0.17.0-sources.jar: software/amazon/awscdk/services/certificatemanager/cloudformation/CertificateResource.java <==
package software.amazon.awscdk.services.certificatemanager.cloudformation;

/**
 * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-certificatemanager-certificate.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.7.10 (build 35934ad)", date = "2018-11-14T09:49:43.455Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.certificatemanager.$Module.class, fqn = "@aws-cdk/aws-certificatemanager.cloudformation.CertificateResource")
public class CertificateResource extends software.amazon.awscdk.Resource {
    protected CertificateResource(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
        super(mode);
    }
    static {
        RESOURCE_TYPE_NAME = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.certificatemanager.cloudformation.CertificateResource.class, "resourceTypeName", java.lang.String.class);
    }
    /**
     * Creates a new ``AWS::CertificateManager::Certificate``.
     * @param parent the ``cdk.Construct`` this ``CertificateResource`` is a part of
     * @param name the name of the resource in the ``cdk.Construct`` tree
     * @param properties the properties of this ``CertificateResource``
     */
    public CertificateResource(final software.amazon.awscdk.Construct parent, final java.lang.String name, final software.amazon.awscdk.services.certificatemanager.cloudformation.CertificateResourceProps properties) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.Jsii);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, java.util.stream.Stream.concat(java.util.stream.Stream.concat(java.util.stream.Stream.of(java.util.Objects.requireNonNull(parent, "parent is required")), java.util.stream.Stream.of(java.util.Objects.requireNonNull(name, "name is required"))), java.util.stream.Stream.of(java.util.Objects.requireNonNull(properties, "properties is required"))).toArray());
    }

    @Override
    protected java.util.Map<java.lang.String, java.lang.Object> renderProperties(final java.lang.Object properties) {
        return this.jsiiCall("renderProperties", java.util.Map.class, java.util.stream.Stream.of(java.util.Objects.requireNonNull(properties, "properties is required")).toArray());
    }
    /**
     * The CloudFormation resource type name for this resource class.
     */
    public final static java.lang.String RESOURCE_TYPE_NAME;

    public java.lang.String getCertificateArn() {
        return this.jsiiGet("certificateArn", java.lang.String.class);
    }

    public software.amazon.awscdk.services.certificatemanager.cloudformation.CertificateResourceProps getPropertyOverrides() {
        return this.jsiiGet("propertyOverrides", software.amazon.awscdk.services.certificatemanager.cloudformation.CertificateResourceProps.class);
    }
    /**
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-certificatemanager-certificate-domainvalidationoption.html
     */
    public static interface DomainValidationOptionProperty extends software.amazon.jsii.JsiiSerializable {
        /**
         * ``CertificateResource.DomainValidationOptionProperty.DomainName``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-certificatemanager-certificate-domainvalidationoption.html#cfn-certificatemanager-certificate-domainvalidationoptions-domainname
         */
        java.lang.Object getDomainName();
        /**
         * ``CertificateResource.DomainValidationOptionProperty.DomainName``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-certificatemanager-certificate-domainvalidationoption.html#cfn-certificatemanager-certificate-domainvalidationoptions-domainname
         */
        void setDomainName(final java.lang.String value);
        /**
         * ``CertificateResource.DomainValidationOptionProperty.DomainName``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-certificatemanager-certificate-domainvalidationoption.html#cfn-certificatemanager-certificate-domainvalidationoptions-domainname
         */
        void setDomainName(final software.amazon.awscdk.Token value);
        /**
         * ``CertificateResource.DomainValidationOptionProperty.ValidationDomain``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-certificatemanager-certificate-domainvalidationoption.html#cfn-certificatemanager-certificate-domainvalidationoption-validationdomain
         */
        java.lang.Object getValidationDomain();
        /**
         * ``CertificateResource.DomainValidationOptionProperty.ValidationDomain``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-certificatemanager-certificate-domainvalidationoption.html#cfn-certificatemanager-certificate-domainvalidationoption-validationdomain
         */
        void setValidationDomain(final java.lang.String value);
        /**
         * ``CertificateResource.DomainValidationOptionProperty.ValidationDomain``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-certificatemanager-certificate-domainvalidationoption.html#cfn-certificatemanager-certificate-domainvalidationoption-validationdomain
         */
        void setValidationDomain(final software.amazon.awscdk.Token value);

        /**
         * @return a {@link Builder} of {@link DomainValidationOptionProperty}
         */
        static Builder builder() {
            return new Builder();
        }

        /**
         * A builder for {@link DomainValidationOptionProperty}
         */
        final class Builder {
            private java.lang.Object _domainName;
            private java.lang.Object _validationDomain;

            /**
             * Sets the value of DomainName
             * @param value ``CertificateResource.DomainValidationOptionProperty.DomainName``
             * @return {@code this}
             */
            public Builder withDomainName(final java.lang.String value) {
                this._domainName = java.util.Objects.requireNonNull(value, "domainName is required");
                return this;
            }
            /**
             * Sets the value of DomainName
             * @param value ``CertificateResource.DomainValidationOptionProperty.DomainName``
             * @return {@code this}
             */
            public Builder withDomainName(final software.amazon.awscdk.Token value) {
                this._domainName = java.util.Objects.requireNonNull(value, "domainName is required");
                return this;
            }
            /**
             * Sets the value of ValidationDomain
             * @param value ``CertificateResource.DomainValidationOptionProperty.ValidationDomain``
             * @return {@code this}
             */
            public Builder withValidationDomain(final java.lang.String value) {
                this._validationDomain = java.util.Objects.requireNonNull(value, "validationDomain is required");
                return this;
            }
            /**
             * Sets the value of ValidationDomain
             * @param value ``CertificateResource.DomainValidationOptionProperty.ValidationDomain``
             * @return {@code this}
             */
            public Builder withValidationDomain(final software.amazon.awscdk.Token value) {
                this._validationDomain = java.util.Objects.requireNonNull(value, "validationDomain is required");
                return this;
            }

            /**
             * Builds the configured instance.
             * @return a new instance of {@link DomainValidationOptionProperty}
             * @throws NullPointerException if any required attribute was not provided
             */
            public DomainValidationOptionProperty build() {
                return new DomainValidationOptionProperty() {
                    private java.lang.Object $domainName = java.util.Objects.requireNonNull(_domainName, "domainName is required");
                    private java.lang.Object $validationDomain = java.util.Objects.requireNonNull(_validationDomain, "validationDomain is required");

                    @Override
                    public java.lang.Object getDomainName() {
                        return this.$domainName;
                    }

                    @Override
                    public void setDomainName(final java.lang.String value) {
                        this.$domainName = java.util.Objects.requireNonNull(value, "domainName is required");
                    }

                    @Override
                    public void setDomainName(final software.amazon.awscdk.Token value) {
                        this.$domainName = java.util.Objects.requireNonNull(value, "domainName is required");
                    }

                    @Override
                    public java.lang.Object getValidationDomain() {
                        return this.$validationDomain;
                    }

                    @Override
                    public void setValidationDomain(final java.lang.String value) {
                        this.$validationDomain = java.util.Objects.requireNonNull(value, "validationDomain is required");
                    }

                    @Override
                    public void setValidationDomain(final software.amazon.awscdk.Token value) {
                        this.$validationDomain = java.util.Objects.requireNonNull(value, "validationDomain is required");
                    }

                };
            }
        }

        /**
         * A proxy class which represents a concrete javascript instance of this type.
         */
        final static class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.certificatemanager.cloudformation.CertificateResource.DomainValidationOptionProperty {
            protected Jsii$Proxy(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
                super(mode);
            }

            /**
             * ``CertificateResource.DomainValidationOptionProperty.DomainName``
             * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-certificatemanager-certificate-domainvalidationoption.html#cfn-certificatemanager-certificate-domainvalidationoptions-domainname
             */
            @Override
            public java.lang.Object getDomainName() {
                return this.jsiiGet("domainName", java.lang.Object.class);
            }

            /**
             * ``CertificateResource.DomainValidationOptionProperty.DomainName``
             * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-certificatemanager-certificate-domainvalidationoption.html#cfn-certificatemanager-certificate-domainvalidationoptions-domainname
             */
            @Override
            public void setDomainName(final java.lang.String value) {
                this.jsiiSet("domainName", java.util.Objects.requireNonNull(value, "domainName is required"));
            }

            /**
             * ``CertificateResource.DomainValidationOptionProperty.DomainName``
             * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-certificatemanager-certificate-domainvalidationoption.html#cfn-certificatemanager-certificate-domainvalidationoptions-domainname
             */
            @Override
            public void setDomainName(final software.amazon.awscdk.Token value) {
                this.jsiiSet("domainName", java.util.Objects.requireNonNull(value, "domainName is required"));
            }

            /**
             * ``CertificateResource.DomainValidationOptionProperty.ValidationDomain``
             * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-certificatemanager-certificate-domainvalidationoption.html#cfn-certificatemanager-certificate-domainvalidationoption-validationdomain
             */
            @Override
            public java.lang.Object getValidationDomain() {
                return this.jsiiGet("validationDomain", java.lang.Object.class);
            }

            /**
             * ``CertificateResource.DomainValidationOptionProperty.ValidationDomain``
             * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-certificatemanager-certificate-domainvalidationoption.html#cfn-certificatemanager-certificate-domainvalidationoption-validationdomain
             */
            @Override
            public void setValidationDomain(final java.lang.String value) {
                this.jsiiSet("validationDomain", java.util.Objects.requireNonNull(value, "validationDomain is required"));
            }

            /**
             * ``CertificateResource.DomainValidationOptionProperty.ValidationDomain``
             * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-certificatemanager-certificate-domainvalidationoption.html#cfn-certificatemanager-certificate-domainvalidationoption-validationdomain
             */
            @Override
            public void setValidationDomain(final software.amazon.awscdk.Token value) {
                this.jsiiSet("validationDomain", java.util.Objects.requireNonNull(value, "validationDomain is required"));
            }
        }
    }
}
